ControlMechanism
================

.. _ControlMechanism_Subtypes:

*Subclasses*

.. toctree::
   :maxdepth: 1

   GatingMechanism
   OptimzationControlMechanism

.. automodule:: psyneulink.core.components.mechanisms.modulatory.control.controlmechanism
   :members:
   :exclude-members: Linear, random, Parameters, control_signals
